# HL History - 1

The course code for this page is **CHW3MZ**.

## Command terms

The following terms are regularly used by IB and have specific meanings:

 - **Analyse**: Break down an idea into its essential elements
 - **Compare**: Identify and justify the similarities between ideas
 - **Contrast**: Identify and justify the differences between ideas
 - **Discuss**: Provide a balanced review with a range of justified opinions or conclusions
 - **Evaluate**: Appraise an argument with strengths and limitations
 - **Examine**: Consider an argument or concept, revealing its assumptions and interrelations
 - **To what extent**: Consider the merits and demerits of an idea or argument with justified opinions or conclusions

## Historiography

Historiography is the study of how history is developed and how historians have viewed history. It helps develop the ability to view events from multiple perspectives and reveals how others might view events in multiple perspectives. The **historical method** outlines the process of making history from start to finish:

 - **Questions are asked** about any of the following:
	- major/minor long-/short-term **causes** of an event
	- the **nature** of an event — the purpose of the event, the status of the event
	- the immediate/long-term/short-term **impacts** of an event
	- the **ethics** of an event
	- a hypothetical **counterfactual** version of an event
 - **Data is collected** to help answer the questions
 - **Data is analysed** to identify patterns and trends via statistics, make judgements using OPCVL, and make comparisons of the main message (content) and PERMS (political, economical, religious, military, social)
 - **Arguments are created** with a thesis and critical analyses per argument
 - and the **findings are communicated** via any means, including essays, opinion paragraphs, debates, presentations, music, etc.

### Lenses

There are seven main schools of thought historians usually fall under that attempt to explain why history happens.

 - The **great people** lens views history with the perspective that individuals create changes, and without those individuals history would be drastically altered. This school focuses on their individual motivations, relationships, etc.
 - The **structuralist** lens views history and events as caused by changes in economic structures, technology, ideology, and social norms.
 - The **decisionist** lens views history with the perspective that it is the decisions of people that are the cause of events.
 - The **Marxist** lens focuses on class conflict — the exploiter and the exploitee and how their conflicts affect history.
 - The **Toynbee** lens regards the response of people to crises as the largest cause to historical events.
 - The **post-modern** lens states that history reflects the time period it was written in and the intent of the author. This school asserts that there is no historical truth and focuses on how history is shaped and manipulated to serve the agendas and needs of various civilisations.
 - The **feminist** lens states that history should reflect the experience of both genders equally. This school particularly focuses on the treatment of and lives of women.

### Historical concepts

There are six key historical concepts that should be taken under consideration in the analysis of history.

 - **Change**: how people and events create change, the differences before and after an event, and the nature and pace of the change
 - **Continuity**: what doesn't change and to what extent things don't change
 - **Causation**: why an event occurred (social, economic, political, etc.), and what factor(s) caused it
 - **Consequence**: the long- and short-term effects of an event on society
 - **Significance**: why the event matters and the importance of some details over others
 - **Perspective**: the different perspectives, why there are different perspectives, and how those perspectives affect the interpretation of history

### Data collection

The abundance of **diverse** data allows for greater perspectives to be gleaned and thus more solutions to a problem. Data and their sources can fall under one of three categories:

 - **Primary** data is from an original source with no sources under it — e.g., newspapers, memoirs, photographs, diaries, etc.
 - **Secondary** data is an interpretation of a primary source(s) with its own argument — e.g., articles, thesises, documentaries, etc.
 - **Tertiary** data compiles secondary sources and should only be used for context — e.g., wikis, textbooks, encyclopedias, etc.

### Logic

!!! definition
    - **Logic** is the study of rules of inference and the analysis of arguments.
    - A **conclusion** is a proposition that follows all others.
    - An **inference** is a connection that acts as a logical leap between a premise and a conclusion.
    - **Logically consistent** statements follow the three laws of thought and do not contradict.
    - **Logically contradicting** statements do not follow the three laws of thought.
    - The **validity** of a statement is its correctness of reasoning via the laws of thought.
    - A **sound** argument is of valid form and has a true premise.
    - An **argument** is a simple statement or disagreement that attempts to reach a conclusion by proving something true with evidence. Good arguments are sound, valid, clear, and avoids hasty conclusions.

**Aristotle** laid the foundations for the principles of formal logic via the three laws of thought.

 - **Law of identity**: everything is identical with itself.
 - **Law of noncontradiction**: contradictory statements cannot both be true.
 - **Law of excluded middle**: any proposition must either be true or false.

!!! example
    - Identity: A football is a football.
    - Noncontradiction: If water and oil do not mix, and substance A mixes in water, it must not be oil.
    - Excluded middle: The Nintendo Switch must either be or not be a potato.

**Deductive** arguments connect a general statement to a more specific statement based on laws, rules, and/or widely accepted principles.

!!! example
    As monkeys like bananas and Lucy is a monkey, Lucy must like bananas.

**Inductive** arguments connect a specific statement to a more general statement based on **empiric** data.

!!! example
    As three of the eight billion humans on Earth are mortal, all humans must be mortal.

### Logical fallacies

 - An **ad hominem** argument attacks the arguer or anything else instead of the argument.
    - e.g., *"You're a Nintendo fanboy; of course you think that."*
 - Arguments that **appeal to authority** use the opinion of an authority on a topic is used as evidence to support an argument.
    - e.g., *"The President of the United States said that we should inject disinfectant into ourselves, so it must be a good idea!"*
 - Arguments that **appeal to emotion** manipulate the recipient's emotions typically via loaded language to win an argument.
    - e.g., *"Those island devils have robbed us of our sleep at night — they must be eradicated!"*
 - Arguments that **appeal to force** use threats to win an argument.
    - e.g., *"I'm right, aren't I?" said the jock, flexing her biceps threateningly.*
 - Arguments that **appeal to ignorance** assert a proposition is true because it has not been proven false.
    - e.g., *"My laptop must secretly have chips in it that no one can detect from aliens because we don't know if there* aren't *undetectable chips in there."*
 - **Bandwagoning or herding** arguments assert that a conclusion is true because it is accepted by most people. This is a result of confirmation bias.
    - e.g., *"Ma, everyone else is jumping off that bridge, so why shouldn't I?"*
 - A fallacy of **accident** wrongly applies a general rule to a specific exception.
    - e.g., *Since surgeons cut people with knives and cutting people with knives is a crime, surgeons are criminals.*
 - An argument that **begs the question** has circular reasoning by having premises that assume its conclusion.
    - e.g., *Acid must be able to eat through your skin because it is corrosive.*
 - **Cherry picking** occurs when evidence that supports the conclusion is pointed out while those that contradict the conclusion are ignored or withheld.
    - e.g., *"Look at these perfect cherries — their tree must be in perfect condition!"*
 - A fallacy of **converse accident** wrongly applies a specific exception to a general rule.
    - e.g., *As the Nintendo Switch, a game console, is portable, all game consoles must be portable.*
 - A **complex question**, also known as a trick question,  embeds a proposition that is accepted when a direct answer is given to the question.
    - e.g., *Have you stopped abusing children yet?*
 - Arguments with a **false cause** incorrectly assume a cause to an effect.
    - e.g., imagining correlation implies causation.
 - **Hasty generalisations** appear in inductive generalisations based on insufficient evidence.
    - e.g., *Since the first seven odd numbers are prime or square, all odd numbers must be prime or square.*
 - Arguments that **miss the point** provide an irrelevant conclusion that fails to address the issue of the question.
    - e.g., *"Is it allowed?" "It should be allowed because it's nowhere near as bad as alcohol."*
 - A **non sequitur** is an invalid argument that does not follow the laws of thought.
    - e.g., *All humans are mammals. Whales are mammals. Therefore, whales are humans.*
 - A **no true Scotsman** (appeal to purity) fallacy takes a generalisation and doubles down to protect it by excluding counterexamples typically via emotionally charged language.
    - e.g., *"Although your father is a Scotsman and dances, no* true *Scotsman would dance."*
 - Arguments with **recency bias** put greater importance on recent data over historic data.
    - e.g., *As GameStop's stock has risen over the past few days dramatically, it will continue to do so.*
 - **Red herrings** change the issue of subject away from the original question.
    - e.g., *You should support the new housing bill. We can't continue to see people living in the streets; we must have cheaper housing.*
 - A **straw man** argument misrepresents the opposing position by making their arguments sound more extreme.
    - e.g., *"We should relax laws on immigration." "The instant we let millions of people through our border is when our country falls."*

## Causes of the Chinese Civil War

### Decline of the Manchu Qing Dynasty
**— Long-term structural political**

In the Qing dynasty, from 1861 to 1908, Empress **Cixi** ruled China as an autocrat. Corruption was rampant in Beijing and officials could not control warlords in remote regions. Under Cixi, China became weak and was easily influenced by foreign powers.

### Foreign involvement
**— Long-term structural political**

The influence of foreign powers increased outrage among citizens at the inability of the government to do things and led to greater internal dissent.

The **opium wars** starting from 1839 were two armed conflicts in China between Western powers and the Qing dynasty. Both were won easily by the West due to their superior, more modern military technology. This resulted in China signing a series of what came to be known as "**unfair treaties**" starting with the Treaty of Nanjing in 1842, which ended the First Opium War and gave Hong Kong to Britain "in perpetuity" among other trading concessions.

The **First Sino-Japanese War** (also known as the War or Jiawu) in 1894–1895 also resulted in Japan's easy victory due to obsolete Chinese military technology.

!!! example
    During the First Sino-Japanese War, Cixi took military money and spent it on palace renovations, demonstrating the corruption in and ineffectiveness of the regime.

### Outdated agricultural practices and limited industrial development
**— Long-term structural economic**

!!! context
    In 1900, Japan and the United States were major industrial powers and both were steadily modernising.

China's rulers believed that Westerners were barbarians and that nothing could be learned from industrialisation. This contributed to their weak military strength as they fell further behind other countries.

!!! example
    By 1914, only ~6 000 km of rail was laid in China while the US had laid ~225 000 km.

Additionally, the population boom meant that demand for food increased, but outdated agricultural practices and technologies could not keep up, resulting in famine.

### Tradition and class structure
**— Long-term structural social**

China operated under a **patriarchy** and had traditions and practices which were thought to be even at the time to be cruel and outdated especially for women.

!!! example
    The life expectancy of a city in China (Shenyang, Daoyi) from 1792 to 1867 was less than 40 years for men and about 30 for women.

**Submission to the Qing dynasty** was traditional as well — the Chinese could not marry Manchus nor live in Manchuria.

!!! example
    Men were required to wear a queue (a long pigtail behind a shaven forehead) to show subservience to the Manchu Empire.

The **class structure** in China did not change for hundreds of years and old traditions and practices persisted into the 1900s.

 - The land peasants worked on belonged to local landlords.
 - 80% of the population remained peasants.
 - Landlords took a large amount of crops as rent and the government also took a large portion as taxes.
 - The burdens from landlords and the government were compounded with natural disasters such as floods and droughts, resulting in famine.
 - Landlords could taken peasant women as they wished, force peasants to perform extra duties, and beat them if they were questioned.

### Internal dissent
**— Long-term structural political**

The **Taiping Civil War** from 1850 to 1864 was one of the bloodiest wars ever and the largest conflict of the 19th century. Anti-Manchurian sentiment was high as the people did not like that the Qing dynasty was ruled not by themselves. At the time, they could not marry Manchus, could not settle in Manchuria, and men were required to wear queues as a reminder of submission to Qing rule.

The **Boxer Rebellion** from 1899 to 1901 was caused by an organisation known as the Boxers (due to many of their members practising Chinese martial arts) desiring an end to foreign control in China. To do so, they violenced across northern China targeting foreign property, Christian missionaries, and Chinese Christians. Although initially supported by Cixi, support was split in the country and eventually she accepted help from foreign armies to end the rebellion.

!!! example
    The slogan of the Boxers was to "support the Qing government and exterminate foreigners".

### Introduction of progressive ideas and rise of revolutionaries

Sun Yixian

### 1911 revolution

failure of revolution
aftermath of revolution

### Warlords
**— Short-term**

warlords

### Rise of revolutionaries 2: electric boogaloo
**— Short-term**

first united front

screw this history too hard

## Consolidation and maintenance of power in China

### Use of legal methods

In the aftermath of the Chinese Civil War, political pluralism was adopted for the purposes of stability and unification. At the **Chinese People's Political Consultative Conference (PCC)** on 21 September 1949:

 - [Mao Zedong](https://en.wikipedia.org/wiki/Mao_Zedong) (Chinese: 毛泽东) was elected Chairman of the People's Republic of China,
 - [Zhou Enlai](https://en.wikipedia.org/wiki/Zhou_Enlai) (Chinese: 周恩来) was appointed first premier (prime minister) by Mao,
 - a de facto constitution in the form of the Organic Law was adopted, and
 - China was divided into six regions with each region under two civilian and two military officers to maintain control

<img src="/resources/images/ccp-hierarchy.png" width=700>(Source: Kognity)</img>

#### Xinjiang

The **reunification campaigns** from 1950 to 1953 consolidated Mao's power across a divided China and allowed him to gain control of its borders.

!!! background
    The region of [Xinjiang](https://en.wikipedia.org/wiki/Xinjiang) followed the Qing dynasty, but was semi-independent during the rule of the warlords and the Republic of China. With a population consisting largely of the [Uyghur](https://en.wikipedia.org/wiki/Uyghurs) minority ethnic group as opposed to the [Han](https://en.wikipedia.org/wiki/Han_Chinese) that made up 98% of the population in China, the province was ruled by a coalition government made of local leaders and **Guomindang (GMD)** members at the time of the establishment of the PRC.

The **Chinese Communist Party (CCP)** was concerned that Xinjiang would start a separatist movement against them or become part of the USSR. Upon the CCP's army, the **People's Liberation Army (PLA)** moving into Xinjiang, provincial authorities pledged allegiance to the CCP and the province was fully under their control by 1951. It is referred to as the "Peaceful Liberation of Xinjiang" in Chinese historiography.

In 1955, the region became an [autonomous region](https://en.wikipedia.org/wiki/Autonomous_regions_of_China) of China, granting it a local government and more legislative rights than other provinces.

#### Controlling the population

All citizens were required to belong to a self-sufficient entity known as a *danwei* (Chinese: 单位), or **work unit**. Permission from the work unit was needed to marry or have children. Under the threat of punishment if policy was not followed, everyone was assigned a home a food to eat along with others in their work unit. Regardless of their size, all work units were obligated to provide or share adequate facilities — schools, housing, health care, etc.

A system of **household registration** to identify citizens known as *hukou* (Chinese: 户口) recorded the birth, death, and movement of people as well as their family members, connecting identifiable information to their location of permanent residence. Whether someone was given better benefits by the government was determined by their agricultural status (agricultural or non-agricultural — i.e. rural or urban, non-agricultural was better) and it was virtually impossible to switch to the other. During industrialisation from 1955 onward, Mao used this system to control rural-to-urban migration by way of a certificate on one's registration required to be able to move to urban area. 

Public **records** per person known as *dang'an* (Chinese: 档案) contained personal information such as:

 - employment records
 - physical characteristics
 - family background with photos
 - transcripts and school records
 - achievements, mistakes, and self-criticisms
 - political activity, and more
 
The government and work unit could access these files, instilling a culture of fear into the citizens as the most intrusive form of surveillance.

#### 1954 Constitution

The [constitution](https://en.wikipedia.org/wiki/1954_Constitution_of_the_People%27s_Republic_of_China) was based on the PCC and Organic Law. It established rights such as equality of citizens andbetween Han and minority groups, prohibiting racial discrimination and oppression. It also set up a legal system where all citizens had the right to a fair trial by judges appointed by the government, but this was not genuinely implemented until after Mao.

### Use of force

#### Hundred Flowers Campaign

From 1956 to 1957, the CCP encouraged citizens to express their thoughts of the regime in the [Hundred Flowers Campaign](https://en.wikipedia.org/wiki/Hundred_Flowers_Campaign) (Chinese: 百花齐放), inviting intellectuals to criticise their policies.

!!! quote "Mao Zedong, 1956:"
    The policy of letting a hundred flowers bloom and a hundred schools of thought contend is designed to promote the flourishing of the arts and the progress of science.

Initially, people were afraid of being arrested publicly and executed after the events of the Three- and Five- Antis campaigns, but eventually began to provide criticism. By May 1957, millions of letters were openly criticising the government. Rallies in the streets and posters and articles in magazines protested against corruption and censorship.

!!! example
    Students at Peking University created a "Democratic Wall" on which they criticised the CCP with posters and letters over their control over intellectuals, the harshness of campaigns against counter-revolutionaries, low living standards, economic corruption and privileges among members of the party.

Mao abandoned the campaign in June 1957 and then began the [Anti-Rightist Campaign](https://en.wikipedia.org/wiki/Anti-Rightist_Campaign) in July where those who provided criticism were not persecuted. It is controversial whether Mao was genuinely surprised by the extent of the criticism or whether the campaign was to identify enemies of the CCP.

!!! definition
    In China, a **rightist** was someone who favoured capitalism over communism, but eventually became a label for anyone who disagreed with Mao.

During the Anti-Rightist Campaign from 1957 to 1959, Mao attacked his critics in the Hundred Flowers Campaign, forcing them to take back what they said. Led by [Deng Xiaoping](https://en.wikipedia.org/wiki/Deng_Xiaoping) (Chinese: 邓小平), at least 550 000 citizens were declared rightists — most of them were sent to be re-educated in the countryside via labour reform. The result was that Mao accumulated more power over the party and over China.

#### Force in the Cultural Revolution

!!! background
    The [**Cultural Revolution**](https://en.wikipedia.org/wiki/Cultural_Revolution) from 1966 to 1976 was declared by Mao to remove all capitalist and intellectual elements from China. In reality, it was Mao's attempt to remove his rivals in the government — [Liu Shaoqi](https://en.wikipedia.org/wiki/Liu_Shaoqi) (Chinese: 刘少奇) and Deng Xiaoping — believing their successful policies would damage his reputation and ideology, and to revive his cult of personality after the events of the Great Leap Forward.

The "Four Olds" — old ideas, culture, customs, and habits — were denounced and books were burnt, porcelain destroyed, museums ransacked, and heritage sites destroyed.

!!! example
    More than 70% of Beijing's cultural artifacts were destroyed in August–September 1966.

Because religion and intellectuals could change people's minds, Mao directed temples, shrines, and religious statues to be destroyed. Intellectuals such as teachers were tortured, beaten to death, and sent to prison. Priests and the clergy were imprisoned and denounced — religious worship was banned entirely. [Red Guards](https://en.wikipedia.org/wiki/Red_Guards) comprising students from elementary to high school carried out humiliations and attacks as per the social norm because Mao had ordered them to.

!!! info
    The **Little Red Book** was a pocket-sized collection of Mao's thoughts, assembled by his propaganda minister, [Lin Biao](https://en.wikipedia.org/wiki/Lin_Biao) (Chinese: 林彪). Published during the Cultural Revolution, it was viewed as the source of all truth and more than a billion copies circulated, second only to the Holy Bible. Members of the Red Guard were required to carry the book with them at all times, and its contents were viewed as the source of all truth.

In addition, landlords, rich peasants, counter-revolutionaries, rightists, and capitalists were all targeted. Due to the vague nature of thse labels, anyone could accuse anyone of anything. An environment of fear formed as people reported suspected enemies, with some citizens reporting neighbours as revenge, and children even reported and condemned their parents. The population was effectively mobilised to act as a **secret police** without actual secret police. Casualties from the Cultural Revolution are difficult to measure and range from thousands to millions.

!!! example
    People were accused and persecuted for crimes such as forgetting a quote from the Little Red Book or owning a Western instrument.

#### Tibet

Declaring that Tibet was part of China, on 7 October 1950, the PLA invaded east Tibet under the banner of liberating them from Western imperialist powers, although the Tibet government recorded only ten foreigners in the country. As a poor country with little infrastructure and communications, the poorly equipped and trained Tibetan army of 8 000 was outmatched by the 40 000 sent by the PLA. On 23 May 1951, the CCP imposed on Tibet the [Seventeen Point Agreement for the Peaceful Liberation of Tibet](https://en.wikipedia.org/wiki/Seventeen_Point_Agreement) that confirmed Chinese soverignity over the province.

In 1959, an [uprising in Tibet](https://en.wikipedia.org/wiki/1959_Tibetan_uprising) led to the mass arrests of Tibetans and increased social and religious control. The spiritual leader of Tibetan Buddhism, the [Dalai Lama](https://en.wikipedia.org/wiki/Dalai_Lama), fled to India and some Buddhist practices were forbidden. The Tenth [Panchen Lama](https://en.wikipedia.org/wiki/Panchen_Lama) under the Dalai Lama wrote the [70 000 Character Petition](https://en.wikipedia.org/wiki/70,000_Character_Petition) addressed to the Chinese government, denouncing the abusive policies such as mass imprisonment and the high prisoner death rate in Tibet under communist rule. Mao rejected the claims and arrested him.

#### Guangdong purge

Guangdong (Chinese: 广东), also known as Canton, is a province in southern China close to Hong Kong and Macau and had held an economically important port that was the headquarters of the GMD. During the **reunification campaigns**, an estimated 28 000 people were executed as it was purged of Nationalist forces.

#### Antis campaigns

The [**Three-Anti Campaign**](https://en.wikipedia.org/wiki/Three-anti_and_Five-anti_Campaigns) in 1951 denounced waste, corruption, and bureaucratic inefficiency. Its targets were CCP members, former GMD members, and bureaucratic officials not in the party. Confessions were required for the people denounced in public trials. An estimated 5% of government officials were purged.

!!! example
    One thousand officers were denounced in the first month — some for minor offenses like the use of an American car and some more serious such as the use of government money to purchase luxury furniture in offices.

The **Five-Anti Campaign** in 1952 denounced bribery, theft of state property, tax evasion, state property theft, chating on government contracts, and stealing economic intelligence. Its targets were the bourgeoisie, merchants, industrialists, and the rest of the capitalist class. The campaign sent a wave of fear in the bourgoisie, not helped by the Chinese encouraged to support the campaign and denounce people they suspected to be guilty. Those convicted also had to confess their crimes in public trials, and an estimated 450 000 private businesses were convicted.

The results of the campaigns were large-scale purges in the CCP and bourgeoisie, the ceoncept of class struggle devevloped in China, and it showed the population that it challenging the regime would be futile.

### Charisma and propaganda

Mao was seen as the figurehead of China and his image was proimently on display throughout China. His Little Red Book was distributed everywhere, and his charisma was a form of control over the population via his **cult of personality**. There was no distinction between Mao the person, the government, and China in the people's eyes. He received little backlash after the events of the Great Leap Forward and most of the population genuinely mourned his death.

!!! example "Example: "Long Live the Chinese Communist Party that Chairman Mao Personally Founded", April 1973"
    <img src="/resources/images/mao-propaganda.jpeg" width=500>(Source: Kognity)</img>

**Propaganda** was under the control of the CCP's Central Propaganda Department up to the Cultural Revolution. Its aims were to spread Chinese ideology and the idea of Maoism against capitalism, indoctrinate the Chinese population, and reinforcce political messages to enhance Mao's cult of personality.

!!! example
    The **Combat Illiteracy Campaign** from 1950 to 1956 sent simple reading material all over China including remote places to increase literacy while spreading ideology and propaganda.

From the 1940s to the 1950s, propaganda was generally colourfully visual because not many could read or write and it was cheaper and quicker to produce. Posters portrayed Mao as a god-like figure and all-powerful, symbolised as the father of the nation. They were put up everywhere in publicc spaces, poor citizens used them to decorate their homes, and Mao's picture was always in newspapers, stamps, and pins.

After 1949, radios and loudspeakers were also extensively used, broadcasting government propaganda and national anthems constantly.

**Role models** of real or fictitious people were used in propaganda to teach the population how to behave.

!!! example
    Lei Fang was a fictitious soldier who died at 22 and was depicted as a happy and positive person despite experiencing a difficult childhood because his immediate family died at an early age. Mao's propaganda minister, Lin Biao, promoted his image by pushing his diary with positive comments about Mao. In 1953, Mao encouraged everyone to learn the "Lei Feng spirit", and the "Learn from Lei Feng" campaign launched during the Cultural Revolution aimed at getting people to obey and be loyal to Mao.

#### Thought Reform Movement

At the same time of the Antis campaigns, the [**Thought Reform Movement**](https://en.wikipedia.org/wiki/Thought_reform_in_China) from 1951 to 1952 was aimed to get the citizens to accept Marxism-Leninism and Maoism. Teachers and college staff were ordered to become Marxist-Leninists, and intellectuals who studied abroad were forced to confess as "implementers of the imperialist cultural invasion". School curricula were restructured, and propaganda and indoctrination were heavily used to change the citizens.

#### Cult of personality

Mao's cult of personality reached its peak during the Cultural Revolution. The people were drawn in by his promises after a decade of wars and corruption after the fall of the Qing dynasty. As the son of a poor peasant who worked hard to improve his social status, he maintained his image of being connected to the land and the peasants.

!!! example
    As a publicity stunt, at the age of 72 years, he swam through the Yangtze River in July 1966 to prove that he was fit to rule. Propaganda at the time claimed he swam nearly 15 kilometres in just over an hour.

#### Education

To create citizens supportive of the state, the CCP controlled the curriculum, reading material, and other information that students were exposed to. Schools effectively became indoctrination centres.

!!! example
    - Chinese textbooks were censored.
    - The Little Red Book was the primary literary text.
    - Elementary education focused on rote (memorisation via repetition) over critical thinking.
    - Secondary education focused on testing, exams, physical education, and in practice it was mostly children of high ranking party members and government officials who attended.

**Language reforms** resulted in a new form of Mandarin that allowed for people averywhere in the country to communicate. This standardisation made Mandarin easier to learn but caused local languages to disappear.

The **Socialist Education Movement** from 1964 to 1966 had the goal to cleanse politics, the economy, organisation, and ideology as the "Four Cleanups". Intellectuals were sent to the countryside to be re-educated by peasants. They still attended school, but also worked in factories and with the peasants.

#### Propaganda in the Cultural Revolution

During the Cultural Revolution, it was required that a portrait or sculpture of Mao was present in each home.

Mao called for class struggle in all educational institutions, and education as an ideal was condemned. Peasants and industrial workers were made teachers and pupils, and they were encouraged to criticise their teachers, who were forced to wear dunce caps and were paraded around. Schools and universities closed down and were made into barracks for Red Guards.

!!! info
    130 million young people stopped attending school.

The [**Down to the Countryside Movement**](https://en.wikipedia.org/wiki/Down_to_the_Countryside_Movement) beginning in 1968 when the Red Guard was becoming violent and difficult to control had Mao order them to return to schools, with more violent radical groups being forcibly suppressed by the PLA. Urban students were sent to the countryside to experience peasant life. This ripped millions of families apart and many did not go back to school or university when they were allowed to return home.

!!! info
    From 1968 to 1976, 17 million young people were sent to rural areas.

#### Arts

Mao's wife, [Jiang Qing](https://en.wikipedia.org/wiki/Jiang_Qing) (Chinese: 江青) was made the chief of new Chinese culture and the "cultural purifier". She imposed censorship on anything that did not meet the criteria of "revolutionary purity".

**Statues** of Mao were erected in front of state offices, universities, and schools.

Traditional Chinese **operas** were replaced by those focused on the proletariat overthrowing class enemies. The more famous ones have political overtones with communist and/or revolutionary themes.

Folk **music** was made modern and an attempt was made to put traditional Chinese music on equal footing. Rousing songs that appealed to the masses were composed, and Western music was entirely banned — symphonic and classical music fell in this category as they were associated with elitism and the West. Mao's poems were put into choral and classical music — the Red Guard sang lyrics derived from the Little Red Book.

**"The East is Red"** was a revolutionary song that was the *de facto* national anthem during the Cultural Revolution. It was played through loudspeakers everywhere at dawn and dusk, sung by students at the beginning of the first class of each day, and shows began with this song.

!!! quote ""The East is Red""
    The east is red, the sun is rising,  
    China has brought forth a Mao Zedong.  
    He works for the people's welfare.  
    Hurrah, he is the people's great saviour.  
    Chairman Mao loves the people,  
    He is our guide,  
    To build a new China,  
    Hurrah, he leads us forward!  
    The Communist Party is like the sun  
    Wherever it shines, it is bright.  
    Wherever there is a Communist Party,  
    Hurrah, there the people are liberated!  

#### Historians

???+ quote "Yan Yen (poet):"
    As a result of the Cultural Revolution, you could say the cultural trademark of my generation is that we had no culture.

???+ quote "Michael Lynch:"
    Cultural terrorism — Result of the Cultural Revolution: Cultural wasteland. Artists who resisted the revolution were sent to re-educational labour camps, where they were brutally treated. Pianists and string players were made to scratch at the ground so they would never be able to play well again.

### Nature, extent, and treatment of opposition

Mao never had any direct opposition.

#### Struggle sessions

Struggle sessions were a form of public humiliation where people **self-criticise** to find the mistakes they made and to free themselves from error. It was used in the USSR from the 1920s and by Mao during the Yan'an Rectification Movement in 1941, the Anti-Rightist Campaign, and the Cultural Revolution.

#### Purges

**Landlords** were publicly humiliated after land reform and tried then executed in their villages until there were no more landlords. Red Guards looted and destroyed homes, attacking landlords and local officials.

!!! info
    An estimated 2-3 million landlorrds were killed.

After Mao's retreat from the Great Leap Forward, in 1966, he decided to reorganise the party by "eliminating members who had taken a capitalist road". In 1968, Liu Shaoqi and Deng Xiaoping were denounced and stripped of their positions. Liu was struggled against and humiliated while the propaganda campaign accused him of being a traitor. He died in November 1969 in prison. Deng was also struggled against and publicly shamed but put under house arrest with his wife, later sent to Jiangxi for re-education through labour.

#### Laojiao and Laogai

[**Laojiao**](https://en.wikipedia.org/wiki/Re-education_through_labor) (Chinese: 劳教)), or re-education through labour, involved sending prisoners to labour camps. Designed to re-educate intellectuals, the goal was for prisoners to live and work with farmers and workers. They were also required to attend political classes where they denounced themselves and criticised their own thinking to realign their thoughts with communism. Those who committed smaller crimes that did not warrant capital punishment were sent here.

[**Laogai**](https://en.wikipedia.org/wiki/Laogai) (Chinese: 劳改), or reform through labour, is a lake in *Avatar: The Last Airbender*. Located in Ba Sing Se in the Earth Kingdom, it hid an underground prison where those interned were brainwashed. It is also compared to the USSR's [*gulag*](https://en.wikipedia.org/wiki/Gulag). As internment camps for criminals, they were built in areas with extreme wewather and interns were forced to perform hard labour such as digging dithes and building roads under extremely poor conditions.

!!! quote
    The Earth King has invited you to Lake Laogai.

### Extent of authoritarian control

As China is still under authoritarian control and many numbers and facts are inaccurate or unknown, it is difficult to obtain concrete information. However, it appears very **totalitarian**.

The Chinese followed **Confucian** philosophy, so social harmony was very important to them. Individuals were expected to accept their position in society and respect authority and the hierarchy. This led to less opposition and greater conformity. Unlike in the West, where the state is viewed as the oppressor, the state was viewed in China as family and the protector of civilisation.

**Maoism** was described as "Marxism adapted to Chinese conditions". It held the following differences compared to Marxism:

 1. Peasants are the **agents of change** as opposed to urban workers, and they are moldable via social engineering. Mao used this to set up his own cult that would keep others in line.
 3. All revolutions require constant renewal, and permanent, **constant revolution** is required to prevent counter-revolution. Mao related stability to dangerous bureaucracy and privileged classes such as imperial China and the USSR under Khrushchev. He used this to justify constant revolution such as the Hundred Flowers Campaign and Cultural Revolution, creating a culture where violent upheaval was a regular way of life.

### Historians

???+ quote "Liang Heng, age 12, recount of late 1967 after 11 million young people travelled to Beijing for Mao:"
    If there was a single thing that meant ecstasy to everyone in those days, it was seeing Chairman Mao. Ever since I had been in Peking, the possibility had been in the back of my mind, and, like every other Red Guard, I would have laid down my life for the chance… On May 1st Peng Ming was planning to go with a small group to conduct performances of Revolutionary songs at the Summer Palace during the day…and I was sometimes asked to carry drums and other instruments, so I went with Peng Ming’s group to the park. We were completely unprepared for what happened. In the middle of singing a song that Peng Ming had composed himself, we heard the great news: Chairman Mao was in the park! Gathering our instruments together hastily, we ran gasping to the spot, but it was too late. He was gone. All that remained of him was the touch of his hand on the hands of a few who had been lucky enough to get close to him. But we didn’t leave in disappointment. That trace of precious warmth in the palms of others seemed to us a more than adequate substitute for the real thing. Those Chairman Mao had touched now became the focus of our fervor. Everyone surged toward them with outstretched arms in hopes of transferring the sacred touch to their own hands. If you couldn’t get close enough for that, then shaking the hand of someone who had shaken the hands with Our Great Saving Star would have to do.

## Foreign policy of China

!!! definition
    **Sinocentrism** is the idea that China is the cultural, political, and/or economic centre of the world.

Mao was concentrated on maintaining and consolidating his power in China, but he supported the idea of an **international communist revolution** and focused on re-establishing China's position as a great power in the world.

After [Joseph Stalin](https://en.wikipedia.org/wiki/Joseph_Stalin)'s death, Mao was seen by many to be the leader of the communist world.

!!! example
    In 1964, China detonated its first nuclear bomb, claiming its necessity for defense and in opposing the "US imperialist policy of nuclear blackmail and nuclear threats". Originally advocating for the abolishment of nuclear weapons but blocked by the US, evidence seems to suggest that Mao was quite willing to use nuclear weapons, believing that China's population would recover quickly.

### Sino-Soviet relations

China's relationship with the USSR started off well enough but steadily deteriorated by the 1960s.

#### Treaty of Friendship, Alliance, and Mutual Assistance

On 16 December 1949, Mao took his first trip abroad to Moscow only a few months after the establishment of the PRC. He was not met with great enthusiasm — Soviet leaders would meet him but would not drink or eat lunch with him, and there were no celebrations upon his arrival. He was in essence treated like a minor politician from a small communist country.

The visit lasted three months and culminated in the signing of the treaty on 14 February 1950. In the [Sino-Soviet Treaty of Friendship, Alliance, and Mutual Assistance](https://en.wikipedia.org/wiki/Sino-Soviet_Treaty_of_Friendship,_Alliance_and_Mutual_Assistance), the USSR:

 - recognised the People's Republic of China as the legitimate government of China
 - lent $300 million over five years to aid economic and logistic recovery from a decade of warfare
 - sent assistance from 11 000+ Soviet consultants and experts to be paid for by the PRC

#### Korean War

!!! background
    From 1910 to August 1945, Korea was occupied by imperial Japan. After the end of World War II, the USSR and the US agreed to temporarily divide Korea along the 38th parallel and established a communist government in the north and a democratic government in the south, respectively.
    <center><img src="/resources/images/korea-map.png" width=350></img></center>
    (Source: Kognity)

Under a desire to unify Korea under communism, North Korean leader [Kim Il-Sung](https://en.wikipedia.org/wiki/Kim_Il-sung) asked Stalin for approval to attack South Korea but was denied due to the [Berlin Blockade](https://en.wikipedia.org/wiki/Berlin_Blockade) at the time. His approval was granted later in April 1950 and the surprise attack launched on 25 June 1950, capturing important cities such as Seoul.

In response, the [United Nations Security Council](https://en.wikipedia.org/wiki/United_Nations_Security_Council) declared North Korea as the aggressor and sent troops from 15 countries led by the US to restore peace under American general [Douglas MacArthur](https://en.wikipedia.org/wiki/Douglas_MacArthur), successfully retaking the 38th parallel.

!!! info
    - The UN motion to send troops only succeeded because the Soviet delegate with [veto powers](https://en.wikipedia.org/wiki/United_Nations_Security_Council_veto_power) was absent as a protest against UN refusal to accept the PRC as the legitimate government of China.
    - The United States, South Korea, and other nations sent 350 000, 400 000, and 50 000 troops, respectively.

!!! background
    - North Korea made significant contributions to the CCP during their liberation of mainland China.
    - Sino-American relations during this time period were especially poor due to the Truman administration declaring their support for the Republic of China on Taiwan as the "main China".

When UN forces crossed the Yalu River on the China-Korea border, Mao felt China's security was at stake and also recognised an opportunity to assert power. Additionally, concern over border security with a hostile east due to a revived Japan, a desire to replace the Soviet influence in North Korea with their own, and Stalin pressing Mao to assist in the war led China to intervene.

In October 1950, the [Chinese People's Volunteers](https://en.wikipedia.org/wiki/People%27s_Volunteer_Army) — in actuality a group of forces from the main People's Liberation Army under a different name to avoid official war with the US — deployed 500 000 troops push the UN troops back to the 38th parallel, resulting in a stalemate back at status quo by 1951. Talks lasted two years with US President [Eisenhower](https://en.wikipedia.org/wiki/Dwight_D._Eisenhower) threatening the use of nuclear weapons should they drag on until an [**armistice**](https://en.wikipedia.org/wiki/Korean_Armistice_Agreement) was signed on 27 July 1953.

???+ info
    **Casualties in the Korean War**  
    <img src="/resources/images/korean-war-casualties.png" width=500>(Source: Kognity)</img>

From China's perspective, the war was both a success and a failure. Mao propagandised the war as a total success in their aim to "Resist America and Defend Korea".

| Success | Failure |
| --- | --- |
| Mao gained considerable prestige for being able to fight the US to a standstill | Heavy casualties — Mao's eldest son was killed in an air raid |
| North Korea remained communist | Sino-American relations deteriorated further, and China faced a total embargo from the US |
| China preserved its Manchurian border where its heavy industry was concentrated | The USSR-lent military equipment had to be repaid |

#### Sino-Soviet split

Stalin and Mao's relationship was tense, and the relationship between the two countries deteriorated much faster under [Nikita Khrushchev](https://en.wikipedia.org/wiki/Nikita_Khrushchev).

!!! background
    The border between the Soviet Union and China was determined by many treaties signed by various officials over many years. This left many gray areas where both countries claimed soverignity.

**Border conflicts** in 1969 between the two countries led to seven months of unofficial conflicts and border clashes over various islands and rivers. At this point in time, both countries had nuclear weapons. Tensions persisted until September 1969 when the Chinese Premier and Soviet Minister of Foreign Affairs met in Beijing in September 1969.

**Personality and ideological conflicts** between the leaders and countries worsened relations. Mao acted like an obedient student and never openly contradicted Stalin while he was in power but was often annoyed by his level of control over the CCP. Stalin was annoyed by Mao's attitude but needed a strong ally.

!!! example
    - In 1921, Mao believed that the rural population would lead China to revolution while Stalin interpreted that the proletariat could only be urban workers.
    - After the end of World War II, Stalin requested Mao to work with the GMD, but Mao decided to wipe out the party and take power instead.

In 1956, after Stalin's death, Khrushchev gave a [secret speech](https://en.wikipedia.org/wiki/On_the_Cult_of_Personality_and_Its_Consequences) denouncing his rule. Mao was alarmed by the brutality of these attacks and interpreted the speech as criticism against him and his own leadership in China.

!!! definition
    - **Détente** between the US and Soviet Union was the relaxation of strained relations between the two countries.
    - **Revisionism** in this context is the betrayal of original revolutionary ideas.
    - **Peaceful coexistence** is the belief that both capitalist and communist nations can exist together without war.

In 1957, Khrushchev organised a [conference in Moscow](https://en.wikipedia.org/wiki/1957_International_Meeting_of_Communist_and_Workers_Parties), inviting all communist states including China. Mao complained about Khrushchev's [revisionism](https://en.wikipedia.org/wiki/Revisionism_(Marxism)) and [peaceful coexistence](https://en.wikipedia.org/wiki/Peaceful_coexistence)/[detente](https://en.wikipedia.org/wiki/D%C3%A9tente) approaches with the United States. Mao believed that it was the duty of communists to conduct class warfare and that the Soviet Union was being too soft on the West by making concessions — they were not fit to lead the communist world. He thought that a final violent conflict was needed with capitalism.

In 1958, Khrushchev was invited to visit China and Mao treated him with disdain, aiming to make his visit unpleasant: the Soviet delegation was placed in a hotel with no AC, Mao invited Khrushchev to swim in his private pool — aware of his inability to swim, and refused any proposals for military cooperation and defense initiatives. In response, Khrushchev pulled most advisors out from China and removed all of them by 1960.

**Chinese meddling in Soviet international affairs** resulted in open defiance against the USSR. Unimpressed with de-Stalinisation, when Albania left the USSR in 1961, China supported them against the Soviet Union, pouring money into the country. In return, Albanian leader Enver Hoxha declared his support for Mao.

Further examples of disagreements during the Sino-Soviet split include:

 - 1958: Mao wanted the USSR to use their first satellite, Sputnik-1, to aid revolutionary efforts, but Khrushchev refused to risk nuclear conflict.
 - 1959: [China invaded Tibet](https://en.wikipedia.org/wiki/Annexation_of_Tibet_by_the_People's_Republic_of_China), but the USSR refused support and withdrew its support from the Chinese nuclear program by refusing to give them a prototype weapon.
 - 1962: China disagreed with the USSR in backing down and making in a deal in the [Cuban Missile Crisis](https://en.wikipedia.org/wiki/Cuban_Missile_Crisis), wanting them to support third world countries in their fight against communism.
 - 1963: China opposed the USSR signing of the [Partial Nuclear Test Ban Treaty](https://en.wikipedia.org/wiki/Partial_Nuclear_Test_Ban_Treaty) against nuclear weapons, sparking a fierce propaganda war.

### Cross-Strait relations

Mao never recognised Taiwan as an independent state.

In the [First Taiwan Strait Crisis](https://en.wikipedia.org/wiki/First_Taiwan_Strait_Crisis) from 1954 to 1955, the PLA bombed various islands near Taiwan and then seized the [Yijiangshan Islands](https://en.wikipedia.org/wiki/Yijiangshan_Islands) in a military conflict. This led to the [Formosa Resolution](https://en.wikipedia.org/wiki/Formosa_Resolution_of_1955) to be enacted by the US Congress — that US forces would defend Taiwan against any attack from the mainland.

In 1958, Mao ordered the PLA to attack the Taiwan-surrounding and -controlled islands of Kinmen and Matsu without discussion with the USSR. As the US prepared for war because of the Formosa Resolution, Mao stood down because he did not have USSR backup. In the aftermath, Khrushchev accused Mao of being a [Trotskyist](https://en.wikipedia.org/wiki/Trotskyism) who had lost all sense of reality.

### Sino-American relations

The US viewed China as an aggressive country with the objective of threatening the security of the non-communist states surrounding it. China viewed the US as their enemy.

!!! example
    The [Red Scares](https://en.wikipedia.org/wiki/Red_Scare) in the US and the anti-American and anti-capitalist propaganda in China (e.g., "Death to the American imperialists") meant that the two countries could not easily communicate diplomatically in public.

To "contain" communism in China, the US signed several treaties such as the [Southeast Asia Treaty Organization](https://en.wikipedia.org/wiki/Southeast_Asia_Treaty_Organization) and the [ANZUS Treaty](https://en.wikipedia.org/wiki/ANZUS) to ward off China. Additionally, they gave the Chinese seat at the UN to Taiwan, pushed allies to avoid entertaining diplomatic relations with Taiwan, supported countries that felt threatened by China, encouraged the split between the USSR and China, and implemented a trade embargo.

From 1970 onward, the two countries began to grow closer — China wanted a new strong ally as Sino-Soviet relations were deteriorating and the US wanted a way out of the Vietnam War.

Taking advantage of [ping-pong diplomacy](https://en.wikipedia.org/wiki/Ping-pong_diplomacy), the exchange of ping-pong players between the US and China, US Secretary of State Henry Kissinger went secretly to meet Chinese Premier Zhou Enlai.

The [**Shanghai Communiqué**](https://en.wikipedia.org/wiki/Shanghai_Communiqu%C3%A9) signed between the two countries on 28 February 1972 was a statement issued by both countries during US President Richard Nixon's visit to China — the first visit to the PRC by any US President — and began the normalisation of relations between them. Nixon described the visit as a mission for peace with the goal to re-establish communications after a generation of hostility, and agreements were reached to expand cultural, educational, and journalistic contracts.

### Historians

???+ quote "*Mao: a Biography* - Ross Terill (revisionist and somewhat sympathetic to Mao), 1995:"
    Mao knew little of the world outside China, and nothing of the capitalist world… Yet Mao took a lively interest in the world beyond the Soviet Bloc during the early 1960s… It was as if the split with Russia in 1960 took a burden off the back of Chinese diplomacy. Instead of being junior partner in someone else’s show, Mao made China its own one-man show on the broadening stage of the Third World.

???+ quote "*Mao: Profiles in Power* - Shaun Breslin, 1998:"
    Mao’s main objective in all of his foreign policy initiative from 1949 to 1976 was to safeguard China’s borders and restore China to its rightful position on the world stage. Mao had a traditional Sinocentrism: the notion that China is the central place in the world, and that only those who recognise and accept Chinese superiority can be considered to be civilised.


???+ quote "*Mao Zedong* - Maurice Meisner (sympathetic to socialist ideology and goals), 2007:"
    Mao’s foreign policy clothed itself in revolutionary rhetoric, but was conservatively cautious in substance, based on narrow calculation of China’s national self-interest… In Mao’s view the Soviet Union posed a greater danger to China than did the United States.

## Resources

 - [IB History Syllabus](/resources/g11/ib-history-syllabus.pdf)
 - [Textbook: Origins and Development of Authoritarian and Single-Party States](/resources/g11/textbook-authoritarian-states.pdf)
 - [Textbook: Causes and Effects of 20th-Century Wars, Second Edition ](/resources/g11/textbook-cause-20-century-wars.pdf)
 - [Textbook: The Move to Global War](/resources/g11/textbook-move-global-war.pdf)
